@@ -3,7 +3,7 @@
 use strict;
 use blib;
 
-use Biblio::Isis;
+use Biblio::Isis 0.24;
 use Getopt::Std;
 
 BEGIN {
@@ -17,15 +17,16 @@ BEGIN {
 }
 
 my %opt;
-getopts('do:l:', \%opt);
+getopts('do:l:v', \%opt);
 
-my $isisdb = shift @ARGV || die "usage: $0 [-o offset] [-l limit] [-d] /path/to/isis/BIBL\n";
+my $isisdb = shift @ARGV || die "usage: $0 [-v] [-o offset] [-l limit] [-d] /path/to/isis/BIBL\n";
 
 my $isis = Biblio::Isis->new (
 	isisdb => $isisdb,
 	debug => $opt{'d'} ? 2 : 0,
-	include_deleted => 1,
+	include_deleted => $opt{'v'},
 #	read_fdt => 1,
+	ignore_empty_subfields => $opt{'v'} ? 0 : 1,
 );
 
 print "rows: ",$isis->count,"\n\n";
